@@ -70,7 +70,7 @@ pub enum ACFanSpeed {
 #[derive(Debug)]
 pub enum SetACSetpoint {
     Maintain,
-    Value(f64),
+    Value(u8),
     /// Decrease by 1 degree celsius.
     Decrease,
     /// Increase by 1 degree celsius.
